<template>
  <div
      :class="`relative block overflow-hidden mb-3 rounded-lg bg-white border border-gray-200 transition-all duration-200`">
    <div
        :class="`flex gap-6 relative  transition duration-100  hover:bg-gray-100 select-none items-center p-3 cursor-pointer ${isOpen  ? 'border-b border-gray-200' : ''}`">
      <input
          class="checkbox checkbox-primary"
          type="checkbox"
          :disabled="total <= 0"
          v-model="isSelectedCatalog"
      >
      <div class="relative block w-full">
        <div class="flex border-b border-gray-200 justify-between items-center gap-2">
          <h3 class="text-md text-gray-700">{{ name }}</h3>
          <div class="flex gap-1 items-center">
            <span :class="`w-2 h-2 ${status ? 'bg-green-500' : 'bg-red-500'} rounded-full`"></span>
            <span>{{ status ? 'Active' : 'Inactive' }}</span>
          </div>
        </div>
        <div class="flex gap-2 pt-3 relative items-center justify-between">
          <span class="relative block font-sm text-gray-400">{{ total }} Items</span>
          <div class="relative flex items-center">
            <button @click="isOpen = !isOpen" class="btn btn-circle btn-primary btn-xs">
              <svg :class="`transition duration-200 fill-current text-white ${isOpen ? 'transform -rotate-180' : ''}`"
                   xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24">
                <path d="M7.41,8.58L12,13.17L16.59,8.58L18,10L12,16L6,10L7.41,8.58Z"/>
              </svg>
            </button>
          </div>
        </div>
      </div>
    </div>

    <div
        :class="`relative block transition-all duration-200 ${isOpen ? 'h-auto opacity-100 visible' : 'h-0 opacity-0 invisible'}`">
      <div class="relative md:pl-16 p-3 block">
        <div
            v-for="product in catalog_products"
            :class="`relative flex gap-4 items-start mb-2 ${product.product_name ? '' : 'hidden'}`">
          <input v-model="selectedProductIds" :value="product.product_id" type="checkbox" class="checkbox checkbox-primary checkbox-sm mt-0.5" />
          <div class="relative block">
            <h4 class="block my-0 text-md">{{ product.product_name }}</h4>
            <span v-if="product.product_variation_id" class="block text-sm text-gray-400">{{ product.variant_value }}</span>
          </div>
        </div>
      </div>
    </div>
  </div>
</template>
<script setup lang="ts">
import Avatar from "../Avatar/Avatar.vue";
import {computed, onMounted, Prop, ref, watch} from "vue";
import {useChatListStore} from "../../stores/chat_list";
import helpers from '../../utils/helpers';

/**
 * Props Interface
 */
interface Props {
  name: string
  is_digital: number
  catalog_products: any
  status: number
  total: number
  idname: number
  isSelected: boolean
}

/**
 * Props Config with Default data
 */
let props = withDefaults(defineProps<Props>(), {
  name: null,
  isSelected: false,
  total: null,
  status: null,
  catalog_products: [],
  is_digital: null,
  idname: null,
});

const emit = defineEmits(['onSelectAll'])

const isSelectedCatalog = ref(false)
const isOpen = ref(false)
const selectedProductIds = ref([])

watch(() => props.isSelected, (val) => {
  console.log(val, 'props is selected')
  isSelectedCatalog.value = val
})

watch(() =>  selectedProductIds.value, (val) => {

  const ids = [...new Set(props.catalog_products.map(x => x.product_id))];
  const distinct = ids.map(id => props.catalog_products.find(x => x.product_id === id));
  console.log(distinct.length, val.length, "SELECTED PRODUCT IDS", ids)
  if (val.length == ids.length) {
    isSelectedCatalog.value = true
    emit("onSelectAll", {id: props.idname, isSelected: true, catalogId: props.idname, productIds: selectedProductIds.value})
  }
  else {
    isSelectedCatalog.value = false
    emit("onSelectAll", {id: props.idname, isSelected: false, catalogId: props.idname, productIds: selectedProductIds.value})
  }

  // if (val.length <= 0) {
  //   isSelectedCatalog.value = false
  // }
})

watch(() => isSelectedCatalog.value, (val, oldValue) => {
  emit("onSelectAll", {id: props.idname, isSelected: val, catalogId: props.idname, productIds: selectedProductIds.value})
  // console.log(val, "IS SELECTED ")
  // emit("onSelectAll", {id: props.idname, isSelected: val})
  // if (val != oldValue) {
  //   if (val) {
  //     let arr = []
  //     props.catalog_products.map((item) => arr.push(item.product_id))
  //     selectedProductIds.value = arr
  //   }
  // } else {
  //   selectedProductIds.value = []
  // }
  // if (!val) {
  //   selectedProductIds.value = []
  // }
})

const onCheckProduct = (product_id) => {
  console.log(product_id)
}
</script>